@@ -3,8 +3,7 @@
 /*               This file is part of the program and library                */
 /*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
 /*                                                                           */
-/* Copyright (C) 2020-2022 Konrad-Zuse-Zentrum                               */
-/*                     fuer Informationstechnik Berlin                       */
+/* Copyright (C) 2020-2024 Zuse Institute Berlin (ZIB)                       */
 /*                                                                           */
 /* This program is free software: you can redistribute it and/or modify      */
 /* it under the terms of the GNU Lesser General Public License as published  */
@@ -28,71 +27,71 @@
 #include <cstdlib>
 #include <new>
 
-static void*
-malloc_default_cb( size_t size, void* )
-{
-   return std::malloc( size );
-}
-
-static void
-free_default_cb( void* ptr, void* )
-{
-   std::free( ptr );
-}
-
-static void* alloc_usrdata = nullptr;
-static void* ( *malloccb )( size_t size, void* usrptr ) = malloc_default_cb;
-static void ( *freecb )( void* ptr, void* usrptr ) = free_default_cb;
-
-template <class T>
-struct CallbackAllocator
-{
-   typedef T value_type;
-
-   CallbackAllocator() noexcept {}
-
-   template <class U>
-   CallbackAllocator( const CallbackAllocator<U>& ) noexcept
-   {
-   }
-   template <class U>
-   bool
-   operator==( const CallbackAllocator<U>& ) const noexcept
-   {
-      return true;
-   }
-   template <class U>
-   bool
-   operator!=( const CallbackAllocator<U>& ) const noexcept
-   {
-      return false;
-   }
-
-   T*
-   allocate( const size_t n ) const
-   {
-      if( n == 0 )
-      {
-         return nullptr;
-      }
-      if( n > static_cast<size_t>( -1 ) / sizeof( T ) )
-      {
-         throw std::bad_array_new_length();
-      }
-      void* const pv = malloccb( n * sizeof( T ), alloc_usrdata );
-      if( !pv )
-      {
-         throw std::bad_alloc();
-      }
-      return static_cast<T*>( pv );
-   }
-
-   void
-   deallocate( T* const p, size_t ) const noexcept
-   {
-      freecb( p, alloc_usrdata );
-   }
-};
+//static void*
+//malloc_default_cb( size_t size, void* )
+//{
+//   return std::malloc( size );
+//}
+//
+//static void
+//free_default_cb( void* ptr, void* )
+//{
+//   std::free( ptr );
+//}
+//
+//static void* alloc_usrdata = nullptr;
+//static void* ( *malloccb )( size_t size, void* usrptr ) = malloc_default_cb;
+//static void ( *freecb )( void* ptr, void* usrptr ) = free_default_cb;
+//
+//template <class T>
+//struct CallbackAllocator
+//{
+//   typedef T value_type;
+//
+//   CallbackAllocator() noexcept {}
+//
+//   template <class U>
+//   CallbackAllocator( const CallbackAllocator<U>& ) noexcept
+//   {
+//   }
+//   template <class U>
+//   bool
+//   operator==( const CallbackAllocator<U>& ) const noexcept
+//   {
+//      return true;
+//   }
+//   template <class U>
+//   bool
+//   operator!=( const CallbackAllocator<U>& ) const noexcept
+//   {
+//      return false;
+//   }
+//
+//   T*
+//   allocate( const size_t n ) const
+//   {
+//      if( n == 0 )
+//      {
+//         return nullptr;
+//      }
+//      if( n > static_cast<size_t>( -1 ) / sizeof( T ) )
+//      {
+//         throw std::bad_array_new_length();
+//      }
+//      void* const pv = malloccb( n * sizeof( T ), alloc_usrdata );
+//      if( !pv )
+//      {
+//         throw std::bad_alloc();
+//      }
+//      return static_cast<T*>( pv );
+//   }
+//
+//   void
+//   deallocate( T* const p, size_t ) const noexcept
+//   {
+//      freecb( p, alloc_usrdata );
+//   }
+//};
 
 #include "papilo/misc/Alloc.hpp"
 using namespace papilo;
@@ -516,7 +515,7 @@ class MessageStream : public std::ostream
 
  public:
    MessageStream( const Message& msg )
-       : messageStreambuf( msg ), std::ostream( &messageStreambuf )
+       : std::ostream( &messageStreambuf ), messageStreambuf( msg )
    {
    }
 };
@@ -1241,7 +1240,6 @@ papilo_solver_start( PAPILO_SOLVER* solver )
                solverInterface->printDetails();
          }
          status = solverInterface->getStatus();
-
          if( status == SolverStatus::kInfeasible )
             fmt::print( "\nsolving detected infeasible problem after {:.3f} seconds\n",
                         solver->solveinfo.solvingtime + solver->solveinfo.presolvetime );
@@ -1252,6 +1250,9 @@ papilo_solver_start( PAPILO_SOLVER* solver )
             fmt::print( "\nsolving detected unbounded or infeasible problem after "
                         "{:.3f} seconds\n",
                         solver->solveinfo.solvingtime + solver->solveinfo.presolvetime );
+         else if( status == SolverStatus::kInterrupted )
+            fmt::print( "\nsolving interrupted after {:.3f} seconds\n",
+                        solver->solveinfo.solvingtime + solver->solveinfo.presolvetime );
          else
             fmt::print( "\nsolving finished after {:.3f} seconds\n",
                         solver->solveinfo.solvingtime + solver->solveinfo.presolvetime );
@@ -1272,7 +1273,7 @@ papilo_solver_start( PAPILO_SOLVER* solver )
          solver->solveinfo.solve_result = PAPILO_SOLVE_RESULT_STOPPED;
 
          if( solverInterface != nullptr &&
-             !solverInterface->getSolution( solution ) )
+             !solverInterface->getSolution( solution, solver->presolveResult.postsolve ) )
             break;
          if( postsolve.undo( solution, solver->solution,
                              solver->presolveResult.postsolve ) ==
@@ -1306,7 +1307,7 @@ papilo_solver_start( PAPILO_SOLVER* solver )
             solver->solveinfo.dualbound = solverInterface->getDualBound();
 
          if( solverInterface != nullptr &&
-             !solverInterface->getSolution( solution ) )
+             !solverInterface->getSolution( solution, solver->presolveResult.postsolve ) )
             break;
 
          if( postsolve.undo( solution, solver->solution,
